summaryrefslogtreecommitdiff
path: root/sw
diff options
context:
space:
mode:
authorNoel Grandin <noel.grandin@collabora.co.uk>2017-08-02 14:30:16 +0200
committerNoel Grandin <noel.grandin@collabora.co.uk>2017-08-03 08:41:07 +0200
commit0b725f98d64f2413d064e487ca7869ac258e6c4e (patch)
tree1e1c0a4941b678f3e3b7f82d73bf03bef411e5c7 /sw
parent14b809550657f9df3a70d533ef54df857d48bc1b (diff)
rename nAnzStrings -> nStringsCnt
Change-Id: I387b702a0bc785a8e9da4e0390067626c5475319 Reviewed-on: https://gerrit.libreoffice.org/40674 Reviewed-by: Noel Grandin <noel.grandin@collabora.co.uk> Tested-by: Noel Grandin <noel.grandin@collabora.co.uk>
Diffstat (limited to 'sw')
-rw-r--r--sw/source/filter/ww8/wrtw8esh.cxx4
-rw-r--r--sw/source/filter/ww8/ww8par3.cxx18
2 files changed, 11 insertions, 11 deletions
diff --git a/sw/source/filter/ww8/wrtw8esh.cxx b/sw/source/filter/ww8/wrtw8esh.cxx
index 62bd24fef2c2..ce1e3df8572c 100644
--- a/sw/source/filter/ww8/wrtw8esh.cxx
+++ b/sw/source/filter/ww8/wrtw8esh.cxx
@@ -398,8 +398,8 @@ void WW8Export::DoComboBox(uno::Reference<beans::XPropertySet> const & xPropSet)
OUString sSelected;
uno::Sequence<OUString> aListItems;
xPropSet->getPropertyValue("StringItemList") >>= aListItems;
- sal_Int32 nNoStrings = aListItems.getLength();
- if (nNoStrings)
+ sal_Int32 nStringsCnt = aListItems.getLength();
+ if (nStringsCnt)
{
uno::Any aTmp = xPropSet->getPropertyValue("DefaultText");
auto pStr = o3tl::tryAccess<OUString>(aTmp);
diff --git a/sw/source/filter/ww8/ww8par3.cxx b/sw/source/filter/ww8/ww8par3.cxx
index 1c8c3ab7cd60..1fa133247822 100644
--- a/sw/source/filter/ww8/ww8par3.cxx
+++ b/sw/source/filter/ww8/ww8par3.cxx
@@ -2201,13 +2201,13 @@ void WW8FormulaControl::FormulaRead(SwWw8ControlType nWhich,
// SSTB (see Spec. 2.2.4)
sal_uInt16 fExtend = 0;
pDataStream->ReadUInt16( fExtend );
- sal_uInt16 nNoStrings = 0;
+ sal_uInt16 nStringsCnt = 0;
// Isn't it that if fExtend isn't 0xFFFF then fExtend actually
// doesn't exist and we really have just read nNoStrings ( or cData )?
if (fExtend != 0xFFFF)
bAllOk = false;
- pDataStream->ReadUInt16( nNoStrings );
+ pDataStream->ReadUInt16( nStringsCnt );
// I guess this should be zero ( and we should ensure that )
sal_uInt16 cbExtra = 0;
@@ -2215,17 +2215,17 @@ void WW8FormulaControl::FormulaRead(SwWw8ControlType nWhich,
OSL_ENSURE(bAllOk, "Unknown formfield dropdown list structure");
if (!bAllOk) //Not as expected, don't risk it at all.
- nNoStrings = 0;
+ nStringsCnt = 0;
const size_t nMinRecordSize = sizeof(sal_uInt16);
const size_t nMaxRecords = pDataStream->remainingSize() / nMinRecordSize;
- if (nNoStrings > nMaxRecords)
+ if (nStringsCnt > nMaxRecords)
{
SAL_WARN("sw.ww8", "Parsing error: " << nMaxRecords <<
- " max possible entries, but " << nNoStrings << " claimed, truncating");
- nNoStrings = nMaxRecords;
+ " max possible entries, but " << nStringsCnt << " claimed, truncating");
+ nStringsCnt = nMaxRecords;
}
- maListEntries.reserve(nNoStrings);
- for (sal_uInt32 nI = 0; nI < nNoStrings; ++nI)
+ maListEntries.reserve(nStringsCnt);
+ for (sal_uInt32 nI = 0; nI < nStringsCnt; ++nI)
{
OUString sEntry = read_uInt16_PascalString(*pDataStream);
maListEntries.push_back(sEntry);
@@ -2201,13 +2201,13 @@ void WW8FormulaControl::FormulaRead(SwWw8ControlType nWhich,
// Isn't it that if fExtend isn't 0xFFFF then fExtend actually
- // doesn't exist and we really have just read nNoStrings ( or cData )?
+ // doesn't exist and we really have just read nStringsCnt ( or cData )?
if (fExtend != 0xFFFF)
bAllOk = false;